@@ -282,6 +282,33 @@ class Integer(Field):
         return str(value)
 
 
+class Json(Field):
+
+    def validate(self, value, redis):
+        value = self.value_or_default(value)
+
+        self.validate_required(value)
+
+        try:
+            if type(value) == dict:
+                return value
+            else:
+                return json.loads(value)
+        except ValueError:
+            raise InvalidFieldError(self.name)
+
+    def recover(self, instance, data, redis):
+        value = data.get(self.name)
+
+        if value == '' or value is None or value == 'None':
+            return None
+
+        return json.loads(value)
+
+    def prepare(self, value):
+        return json.dumps(value)
+
+
 class Float(Field):
 
     def validate(self, instance, value, redis):
@@ -552,7 +579,7 @@ class SingleRelationManager:
         prev = getattr(self.instance, self.name).get()
 
         if prev is not None and self.inverse:
-            getattr(prev.proxy, self.inverse)._unrelate(self.instance, redis)
+            getattr(prev, self.inverse)._unrelate(self.instance, redis)
 
         if obj is None:
             redis.hdel(self.instance.key(), self.name)
