@@ -1,13 +1,16 @@
+import os
+
+import pytest
+
 from coralillo import Engine, Model, fields
 from coralillo.auth import PermissionHolder
-import pytest
 
 from .models import bound_models
 
 
 @pytest.fixture
 def nrm():
-    nrm = Engine()
+    nrm = Engine(host=os.getenv('REDIS_HOST', 'localhost'))
 
     nrm.lua.drop(args=['*'])
 
