@@ -1,7 +1,7 @@
 from collections.abc import Iterable
 from coralillo.datamodel import debyte_string
 from coralillo.errors import ModelNotFoundError
-from .models import House, Table, Ship, Tenanted, SideWalk, Pet
+from .models import House, Table, Ship, Tenanted, SideWalk, Pet, Dog
 import pytest
 
 
@@ -70,9 +70,72 @@ def test_filter(nrm):
 
     assert res == [pets[1].id]
 
+    res = list(map(
+        lambda x: x.id,
+        Pet.q().filter(name__in=('ab', 'bd'))
+    ))
+
+    assert res == [pets[1].id]
+
     assert Pet.q().filter(name='bd').one() == pets[1]
 
 
+def test_filter_json_field(nrm):
+    with pytest.raises(AttributeError) as excinfo:
+        Dog.q().filter(data__gt__eq=True)
+
+    assert str(excinfo.value) == 'Filter gt is reserved'
+
+    pets = [
+        Dog(name='Rufus', data={
+            'breed': 'labrador',
+            'owner': {
+                'name': 'Bob',
+                'other_pets': [{
+                    'name': 'Fishy',
+                }],
+            },
+        }).save(),  # 0
+        Dog(name='Meg', data={
+            'breed': 'collie', 'owner': None,
+        }).save(),  # 1
+    ]
+
+    res = list(map(
+        lambda x: x.id,
+        Dog.q().filter(data__breed='collie')
+    ))
+
+    assert res == [pets[1].id]
+
+    res = list(map(
+        lambda x: x.id,
+        Dog.q().filter(data__owner__name='Bob')
+    ))
+
+    assert res == [pets[0].id]
+
+    res = list(map(
+        lambda x: x.id,
+        Dog.q().filter(data__owner__other_pets__0__name='Fishy'),
+    ))
+
+    assert res == [pets[0].id]
+
+    pets.append(
+        Dog(name='Shep', data={
+            'breed': 'collie',
+        }).save(),  # 2
+    )
+
+    res = list(map(
+        lambda x: x.id,
+        Dog.q().filter(data__owner__isnull=True),
+    ))
+
+    assert res == [pets[2].id]
+
+
 def test_update_keep_index(nrm):
     ship = Ship(name='the ship', code='TS').save()
 
